"""Configuration module for FAL avatar generation."""

from .constants import (
    MODEL_ENDPOINTS,
    MODEL_DISPLAY_NAMES,
    MODEL_PRICING,
    MODEL_DEFAULTS,
    SUPPORTED_RESOLUTIONS,
    SUPPORTED_ASPECT_RATIOS,
    MAX_DURATIONS,
    PROCESSING_TIME_ESTIMATES,
    INPUT_REQUIREMENTS,
    MODEL_CATEGORIES,
    MODEL_RECOMMENDATIONS,
)

__all__ = [
    "MODEL_ENDPOINTS",
    "MODEL_DISPLAY_NAMES",
    "MODEL_PRICING",
    "MODEL_DEFAULTS",
    "SUPPORTED_RESOLUTIONS",
    "SUPPORTED_ASPECT_RATIOS",
    "MAX_DURATIONS",
    "PROCESSING_TIME_ESTIMATES",
    "INPUT_REQUIREMENTS",
    "MODEL_CATEGORIES",
    "MODEL_RECOMMENDATIONS",
]
